@@ -221,15 +221,18 @@ class DB:
         hashed_key_name = self._hash_name(key.name)
         expression_names[f"#{hashed_key_name}"] = key.name
 
+        kwargs = {
+            "Key": key.as_dynamodb_key(),
+            "UpdateExpression": expression,
+            "ExpressionAttributeNames": expression_names,
+            # make sure that item is being updated, not created
+            "ConditionExpression": f"attribute_exists(#{hashed_key_name})",
+        }
+        if expression_values:
+            kwargs["ExpressionAttributeValues"] = expression_values
+
         try:
-            self._table.update_item(
-                Key=key.as_dynamodb_key(),
-                UpdateExpression=expression,
-                ExpressionAttributeNames=expression_names,
-                ExpressionAttributeValues=expression_values,
-                # make sure that item is being updated, not created
-                ConditionExpression=f"attribute_exists(#{hashed_key_name})",
-            )
+            self._table.update_item(**kwargs)
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
 
